==> jc-1.4.0.tar.gz: gnu/java/rmi/dgc/DGCImpl__5fSkel.h <==
// public final class gnu.java.rmi.dgc.DGCImpl_Skel

// class file dependencies
// @dep_class b85fb793c983aec6 gnu_java_rmi_dgc_DGCImpl__5fSkel
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_dgc_DGCImpl__5fSkel_H_
#define _JC_gnu_java_rmi_dgc_DGCImpl__5fSkel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_server_RemoteCall$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_refs	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$refs	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object;

typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$fields_struct	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$fields_struct;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vmethods	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vmethods;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtable	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtable;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$fields_struct {
	_jc_object_array	*operations;
	jlong	interfaceHash;
};
extern _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$fields_struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *);

// Virtual methods
extern void _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method$dispatch$1fd544da7f6d20a7(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *, struct _jc_object *, struct _jc_object *, jint, jlong);
extern _jc_object_array *_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method$getOperations$c687144a670df424(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method_info$dispatch$1fd544da7f6d20a7;
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method_info$getOperations$c687144a670df424;

// Static methods
extern void _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vmethods {
	void	(*dispatch$1fd544da7f6d20a7)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *, struct _jc_object *, struct _jc_object *, jint, jlong);
	_jc_object_array	*(*getOperations$c687144a670df424)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *);
};

// Vtable
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vmethods	gnu_java_rmi_dgc_DGCImpl__5fSkel;
};

// Vtype
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$refs {
    _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_refs	gnu_java_rmi_dgc_DGCImpl__5fSkel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_nonrefs	gnu_java_rmi_dgc_DGCImpl__5fSkel;
};

// Object instance structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object {
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype	*vtype;
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_dgc_DGCImpl__5fSkel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$class_object;

#endif	/* _JC_gnu_java_rmi_dgc_DGCImpl__5fSkel_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/dgc/DGCImpl__5fSkel.h <==
// public final class gnu.java.rmi.dgc.DGCImpl_Skel

// class file dependencies
// @dep_class b85fb793c983aec6 gnu_java_rmi_dgc_DGCImpl__5fSkel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_dgc_DGCImpl__5fSkel_H_
#define _JC_gnu_java_rmi_dgc_DGCImpl__5fSkel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_server_RemoteCall$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_refs	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$refs	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object;

typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$fields_struct	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$fields_struct;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vmethods	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vmethods;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtable	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtable;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$fields_struct {
	_jc_object_array	*operations;
	jlong	interfaceHash;
};
extern _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$fields_struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method$dispatch$1fd544da7f6d20a7(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *, struct _jc_object *, struct _jc_object *, jint, jlong) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method$getOperations$c687144a670df424(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method_info$dispatch$1fd544da7f6d20a7;
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method_info$getOperations$c687144a670df424;

// Static methods
extern void _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vmethods {
	void	(*dispatch$1fd544da7f6d20a7)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *, struct _jc_object *, struct _jc_object *, jint, jlong) _JC_JCNI_ATTR;
	_jc_object_array	*(*getOperations$c687144a670df424)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vmethods	gnu_java_rmi_dgc_DGCImpl__5fSkel;
};

// Vtype
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$refs {
    _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_refs	gnu_java_rmi_dgc_DGCImpl__5fSkel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$sub_nonrefs	gnu_java_rmi_dgc_DGCImpl__5fSkel;
};

// Object instance structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$object {
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype	*vtype;
	_jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$vtype _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_dgc_DGCImpl__5fSkel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_dgc_DGCImpl__5fSkel$class_object;

#endif	/* _JC_gnu_java_rmi_dgc_DGCImpl__5fSkel_H_ */
